Welcome to the polsalt documentation!   polsalt is is a package for
reducing polarimetric observations from the Robert Stobie Spectrograph on
the Southern African Large Telescope.   

Documentation
=============

The documentation for this package is here:

.. toctree::
  :maxdepth: 2

  polsalt/intro.rst

.. toctree::
  :maxdepth: 1
         
.. automodapi:: polsalt 

